@@ -2,9 +2,11 @@ import React from "react";
 import { Provider } from "react-redux";
 import { createStore } from "../../../redux/store";
 import Settings from "../../../components/settings/Settings";
+import { getLayersWithDefaultProps } from "../../../../DeckGLMap/layers/utils/layerTools";
 
 const exampleData = require("../../../../../../demo/example-data/deckgl-map.json");
-const store = createStore(exampleData[0].deckglSpecBase, (patch) => patch);
+const layers = getLayersWithDefaultProps(exampleData[0].layers);
+const store = createStore(layers);
 
 export default {
     component: Settings,
